import React, { PropsWithChildren } from 'react';

import {
  type ConversationListContentProps,
  ConversationListContent as DefaultConversationListContent,
} from '../ConversationListContent';
import {
  type ConversationListHeaderProps,
  ConversationListHeader as DefaultConversationListHeader,
} from '../ConversationListHeader';

import { ConversationCreate }  from '../ConversationCreate';

import {
  ConversationListProvider,
  ConversationListProviderProps,
  useConversationListContext,
} from '../../context/ConversationListContext';

interface IConversationListProps extends ConversationListProviderProps {
  List?: React.ComponentType<ConversationListHeaderProps>;
  Header?: React.ComponentType<ConversationListContentProps>;
}

function ConversationListComponent(props: PropsWithChildren<IConversationListProps>) {
  const {
    children,
    List = DefaultConversationListContent,
    Header = DefaultConversationListHeader,
  } = props;

  const { conversationList } = useConversationListContext();
  return (
    <>
      {children || (
        <>
          <Header />
          <List conversationList={conversationList} />
          <ConversationCreate />
        </>
      )}
    </>
  );
}

function UnMemoizedConversationList( props: IConversationListProps):React.ReactElement {
  return (
    <ConversationListProvider {...props}>
      <ConversationListComponent {...props} />
    </ConversationListProvider>
  );
}

export const ConversationList = React.memo(UnMemoizedConversationList) as typeof UnMemoizedConversationList;

